#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const meow = require("meow");
const termd_1 = __importStar(require("./src/termd"));
const utils_1 = require("./src/utils");
const cli = meow(`
  Usage
    $ termd <filename>

  Options
    --string, -s    Use a string with markdown syntax
    --url, -u       Render markdown from url in the terminal
    --npm, -n       Render npm package readme in the terminal
    --github, -g    Render github repository readme in the terminal

  Examples
    $ termd readme.md // # Heading 1
    ${termd_1.renderString('# Heading 1')}
    $ termd -s "# Heading 1"
    ${termd_1.renderString('# Heading 1')}
    $ termd --url="https://gist.githubusercontent.com/dephraiim/..."
    ${termd_1.renderString('# Heading 1')}
    $ termd -n termd
    ...

    $ termd --github="dephraiim/termd"
    ...
`);
try {
    if (cli.input[0]) {
        console.log(termd_1.default(cli.input[0]));
    }
    if (cli.flags.s || cli.flags.string) {
        let optionString = cli.flags.s || cli.flags.string;
        console.log(termd_1.renderString(optionString));
    }
    if (cli.flags.u || cli.flags.url) {
        let url = cli.flags.u || cli.flags.url;
        utils_1.getMarkdownFromUrl(url)
            .then((string) => console.log(termd_1.renderString(string)))
            .catch((e) => {
            throw new Error(e);
        });
    }
    if (cli.flags.n || cli.flags.npm) {
        let packageName = cli.flags.n || cli.flags.npm;
        let packageUrl = utils_1.npmPackageUrl(packageName);
        utils_1.getMarkdownFromUrl(packageUrl)
            .then((data) => data.readme)
            .then((readme) => console.log(termd_1.renderString(readme)))
            .catch((e) => {
            throw new Error(e);
        });
    }
    if (cli.flags.g || cli.flags.github) {
        let repoName = cli.flags.github || cli.flags.g;
        let repoUrl = utils_1.githubReadmeUrl(repoName);
        utils_1.getMarkdownFromUrl(repoUrl)
            .then((data) => data.content)
            .then((data64) => {
            let buffer = Buffer.from(data64, 'base64');
            return buffer.toString('utf-8');
        })
            .then((readme) => console.log(termd_1.renderString(readme)))
            .catch((e) => {
            throw new Error(e);
        });
    }
}
catch (error) {
    console.log(error.message);
}
