"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.githubReadmeUrl = exports.npmPackageUrl = exports.getMarkdownFromUrl = exports.prettifyTable = exports.isMarkdownTable = exports.toMarkdown = exports.toAst = void 0;
const unified_1 = __importDefault(require("unified"));
const remark_parse_1 = __importDefault(require("remark-parse"));
const remark_stringify_1 = __importDefault(require("remark-stringify"));
const marktable_1 = __importDefault(require("marktable"));
const cli_table_1 = __importDefault(require("cli-table"));
const axios_1 = __importDefault(require("axios"));
const toAst = (markdown) => {
    return unified_1.default().use(remark_parse_1.default).parse(markdown);
};
exports.toAst = toAst;
const toMarkdown = (node) => {
    return unified_1.default().use(remark_stringify_1.default).stringify(node);
};
exports.toMarkdown = toMarkdown;
const isMarkdownTable = (text) => {
    // https://github.com/erikvullings/slimdown-js/blob/master/src/slimdown.ts 125
    return /(\|[^\n]+\|\r?\n)((?:\|:?[-]+:?)+\|)(\n(?:\|[^\n]+\|\r?\n?)*)?/g.test(text);
};
exports.isMarkdownTable = isMarkdownTable;
const prettifyTable = (mdt) => {
    let parsedTable = marktable_1.default(mdt);
    let tableArray = parsedTable
        .trim()
        .split('\n')
        .map((s) => s
        .split('|')
        .filter((c) => !c.includes('-'))
        .filter((d) => /\s+/.test(d)))
        .filter((e) => e.length > 1);
    const table = new cli_table_1.default({
        head: tableArray.shift(),
        chars: {
            top: '═',
            'top-mid': '╤',
            'top-left': '╔',
            'top-right': '╗',
            bottom: '═',
            'bottom-mid': '╧',
            'bottom-left': '╚',
            'bottom-right': '╝',
            left: '║',
            'left-mid': '╟',
            mid: '─',
            'mid-mid': '┼',
            right: '║',
            'right-mid': '╢',
            middle: '│',
        },
    });
    tableArray.forEach((e) => {
        table.push(e);
    });
    return table.toString();
};
exports.prettifyTable = prettifyTable;
const getMarkdownFromUrl = (url) => __awaiter(void 0, void 0, void 0, function* () {
    const requestData = yield axios_1.default.get(url);
    return requestData.data;
});
exports.getMarkdownFromUrl = getMarkdownFromUrl;
const npmPackageUrl = (packageName) => {
    const NPM_REGISTRY = 'https://registry.npmjs.com/';
    return NPM_REGISTRY + packageName;
};
exports.npmPackageUrl = npmPackageUrl;
const githubReadmeUrl = (repoName) => {
    const GITHUB_URL = `https://api.github.com/repos/${repoName}/readme`;
    return GITHUB_URL;
};
exports.githubReadmeUrl = githubReadmeUrl;
